package com.health.consultation.config;

import lombok.Data;
import org.eclipse.paho.client.mqttv3.*;
import org.eclipse.paho.client.mqttv3.persist.MemoryPersistence;
import org.springframework.context.annotation.Configuration;

/**
 * mqtt配置类
 * @author Administrator
 */
@Configuration
@Data
public class MQTTConnect {

        private String broker;
        private String username;
        private String password;
        private MqttClient  client;

    public void setBroker(String broker) {
        this.broker = broker;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public MqttClient connect() throws MqttException {
        client = new MqttClient(broker, MqttClient.generateClientId(), new MemoryPersistence());

        MqttConnectOptions options = new MqttConnectOptions();
        options.setUserName(username);
        options.setPassword(password.toCharArray());
        options.setConnectionTimeout(60);
        options.setKeepAliveInterval(60);

        return client;
    }

    public void disconnect() throws MqttException {
        if (client != null && client.isConnected()) {
            client.disconnect();
            client.close();
        }
    }

    public void publishMessage(String topic, String content, int qos) throws MqttException {
        MqttMessage message = new MqttMessage(content.getBytes());
        message.setQos(qos);
        client.publish(topic, message);
    }

    public void subscribeTopic(String topic, IMqttMessageListener listener) throws MqttException {
        client.subscribe(topic, listener);
    }
}





